@@ -4,7 +4,6 @@ import typing
 
 try:
     from numpy import (
-        ndarray,
         radians,
         sin,
         cos,
@@ -14,25 +13,21 @@ try:
         degrees,
         arctan2 as atan2,
         sqrt,
-        pi,
+        finfo,
+        where,
     )
+    from .eci import eci2ecef, ecef2eci
 except ImportError:
-    from math import radians, sin, cos, tan, atan, hypot, degrees, atan2, sqrt, pi  # type: ignore
-
-    ndarray = typing.Any  # type: ignore
+    from math import radians, sin, cos, tan, atan, hypot, degrees, atan2, sqrt  # type: ignore
 
+from math import pi
 from datetime import datetime
 
 from .ellipsoid import Ellipsoid
 from .utils import sanitize
 
-try:
-    from .eci import eci2ecef, ecef2eci
-except ImportError:
-    eci2ecef = ecef2eci = None
-
-# py < 3.6 compatible
-tau = 2 * pi
+if typing.TYPE_CHECKING:
+    from numpy import ndarray
 
 
 __all__ = [
@@ -93,8 +88,7 @@ def geodetic2ecef(
     N = ell.semimajor_axis ** 2 / sqrt(
         ell.semimajor_axis ** 2 * cos(lat) ** 2 + ell.semiminor_axis ** 2 * sin(lat) ** 2
     )
-    # Compute cartesian (geocentric) coordinates given  (curvilinear) geodetic
-    # coordinates.
+    # Compute cartesian (geocentric) coordinates given (curvilinear) geodetic coordinates.
     x = (N + alt) * cos(lat) * cos(lon)
     y = (N + alt) * cos(lat) * sin(lon)
     z = (N * (ell.semiminor_axis / ell.semimajor_axis) ** 2 + alt) * sin(lat)
@@ -163,18 +157,36 @@ def ecef2geodetic(
             Beta = -pi / 2
 
     # eqn. 13
-    eps = ((ell.semiminor_axis * u - ell.semimajor_axis * huE + E ** 2) * sin(Beta)) / (
+    dBeta = ((ell.semiminor_axis * u - ell.semimajor_axis * huE + E ** 2) * sin(Beta)) / (
         ell.semimajor_axis * huE * 1 / cos(Beta) - E ** 2 * cos(Beta)
     )
 
-    Beta += eps
+    Beta += dBeta
+
+    # eqn. 4c
     # %% final output
     lat = atan(ell.semimajor_axis / ell.semiminor_axis * tan(Beta))
 
+    try:
+        # patch latitude for float32 precision loss
+        lim_pi2 = pi / 2 - finfo(dBeta.dtype).eps
+        lat = where(Beta >= lim_pi2, pi / 2, lat)
+        lat = where(Beta <= -lim_pi2, -pi / 2, lat)
+    except NameError:
+        pass
+
     lon = atan2(y, x)
 
     # eqn. 7
-    alt = hypot(z - ell.semiminor_axis * sin(Beta), Q - ell.semimajor_axis * cos(Beta))
+    cosBeta = cos(Beta)
+    try:
+        # patch altitude for float32 precision loss
+        cosBeta = where(Beta >= lim_pi2, 0, cosBeta)
+        cosBeta = where(Beta <= -lim_pi2, 0, cosBeta)
+    except NameError:
+        pass
+
+    alt = hypot(z - ell.semiminor_axis * sin(Beta), Q - ell.semimajor_axis * cosBeta)
 
     # inside ellipsoid?
     inside = (
@@ -408,10 +420,11 @@ def eci2geodetic(
 
     eci2geodetic() a.k.a. eci2lla()
     """
-    if eci2ecef is None:
-        raise ImportError("pip install numpy")
 
-    xecef, yecef, zecef = eci2ecef(x, y, z, t, use_astropy=use_astropy)
+    try:
+        xecef, yecef, zecef = eci2ecef(x, y, z, t, use_astropy=use_astropy)
+    except NameError:
+        raise ImportError("pip install numpy")
 
     return ecef2geodetic(xecef, yecef, zecef, ell, deg)
 
@@ -459,12 +472,13 @@ def geodetic2eci(
 
     geodetic2eci() a.k.a lla2eci()
     """
-    if ecef2eci is None:
-        raise ImportError("pip install numpy")
 
     x, y, z = geodetic2ecef(lat, lon, alt, ell, deg)
 
-    return ecef2eci(x, y, z, t, use_astropy=use_astropy)
+    try:
+        return ecef2eci(x, y, z, t, use_astropy=use_astropy)
+    except NameError:
+        raise ImportError("pip install numpy")
 
 
 def enu2ecef(
