@@ -2,8 +2,9 @@
 
 from __future__ import annotations
 
+import typing
 from datetime import datetime
-from numpy import ndarray, array, sin, cos, column_stack, empty, atleast_1d
+from numpy import array, sin, cos, column_stack, empty, atleast_1d
 
 try:
     from astropy.coordinates import GCRS, ITRS, EarthLocation, CartesianRepresentation
@@ -14,16 +15,14 @@ except ImportError:
 
 from .sidereal import greenwichsrt, juliandate
 
+if typing.TYPE_CHECKING:
+    from numpy import ndarray
+
 __all__ = ["eci2ecef", "ecef2eci"]
 
 
 def eci2ecef(
-    x: float | ndarray,
-    y: float | ndarray,
-    z: float | ndarray,
-    time: datetime,
-    *,
-    use_astropy: bool = True
+    x: ndarray, y: ndarray, z: ndarray, time: datetime, *, use_astropy: bool = True
 ) -> tuple[ndarray, ndarray, ndarray]:
     """
     Observer => Point  ECI  =>  ECEF
@@ -81,12 +80,7 @@ def eci2ecef(
 
 
 def ecef2eci(
-    x: float | ndarray,
-    y: float | ndarray,
-    z: float | ndarray,
-    time: datetime,
-    *,
-    use_astropy: bool = True
+    x: ndarray, y: ndarray, z: ndarray, time: datetime, *, use_astropy: bool = True
 ) -> tuple[ndarray, ndarray, ndarray]:
     """
     Point => Point   ECEF => ECI
