@@ -4,14 +4,14 @@ from __future__ import annotations
 import typing
 
 try:
-    from numpy import radians, degrees, cos, arctan2 as atan2, tan, pi, ndarray, atleast_1d
+    from numpy import radians, degrees, cos, arctan2 as atan2, tan, array, broadcast_arrays
 except ImportError:
-    from math import radians, degrees, cos, atan2, tan, pi  # type: ignore
+    from math import radians, degrees, cos, atan2, tan  # type: ignore
 
-    ndarray = typing.Any  # type: ignore
+from math import pi, tau
 
-import typing
 from .ellipsoid import Ellipsoid
+from .utils import sign
 from . import rcurve
 from . import rsphere
 from .latitude import (
@@ -23,6 +23,9 @@ from .latitude import (
 )
 from .utils import sph2cart, cart2sph
 
+if typing.TYPE_CHECKING:
+    from numpy import ndarray
+
 __all__ = [
     "loxodrome_inverse",
     "loxodrome_direct",
@@ -33,6 +36,9 @@ __all__ = [
 ]
 
 
+COS_EPS = 1e-9
+
+
 def meridian_dist(lat: ndarray, ell: Ellipsoid = None, deg: bool = True) -> float:
     """
     Computes the ground distance on an ellipsoid from the equator to the input latitude.
@@ -138,6 +144,12 @@ def loxodrome_inverse(
     if deg:
         lat1, lon1, lat2, lon2 = radians(lat1), radians(lon1), radians(lat2), radians(lon2)
 
+    try:
+        lat1, lon1, lat2, lon2 = broadcast_arrays(lat1, lon1, lat2, lon2)
+
+    except NameError:
+        pass
+
     # compute changes in isometric latitude and longitude between points
     disolat = geodetic2isometric(lat2, deg=False, ell=ell) - geodetic2isometric(
         lat1, deg=False, ell=ell
@@ -146,35 +158,41 @@ def loxodrome_inverse(
 
     # compute azimuth
     az12 = atan2(dlon, disolat)
-    cosaz12 = cos(az12)
+    aux = abs(cos(az12))
 
     # compute distance along loxodromic curve
-    dist = meridian_arc(lat2, lat1, deg=False, ell=ell) / abs(cos(az12))
+    dist = meridian_arc(lat2, lat1, deg=False, ell=ell) / aux
+
+    # straight east or west
+    i = aux < COS_EPS
     try:
-        if (abs(cosaz12) < 1e-9).any():
-            dist[abs(cosaz12) < 1e-9] = departure(lon2, lon1, lat1, ell, deg=False)
+        dist[i] = departure(lon2[i], lon1[i], lat1[i], ell, deg=False)
     except (AttributeError, TypeError):
-        if abs(cosaz12) < 1e-9:  # straight east or west
+        if i:
             dist = departure(lon2, lon1, lat1, ell, deg=False)
 
     if deg:
         az12 = degrees(az12) % 360.0
 
-    return dist, az12
+    try:
+        return dist.squeeze()[()], az12.squeeze()[()]
+    except AttributeError:
+        return dist, az12
 
 
 def loxodrome_direct(
-    lat1: ndarray,
-    lon1: ndarray,
-    rng: ndarray,
+    lat1: float | ndarray,
+    lon1: float | ndarray,
+    rng: float | ndarray,
     a12: float,
     ell: Ellipsoid = None,
     deg: bool = True,
-) -> tuple[ndarray, ndarray]:
+) -> tuple[float | ndarray, float | ndarray]:
     """
     Given starting lat, lon with arclength and azimuth, compute final lat, lon
 
     like Matlab reckon('rh', ...)
+    except that "rng" in meters instead of "arclen" degrees of arc
 
     Parameters
     ----------
@@ -202,15 +220,16 @@ def loxodrome_direct(
     if deg:
         lat1, lon1, a12 = radians(lat1), radians(lon1), radians(a12)
 
+    a12 = a12 % tau
+
     try:
-        lat1 = atleast_1d(lat1)
-        rng = atleast_1d(rng)
-        if (abs(lat1) > pi / 2).any():
+        lat1, rng, a12 = broadcast_arrays(lat1, rng, a12)
+        if (abs(lat1) > pi / 2).any():  # type: ignore
             raise ValueError("-90 <= latitude <= 90")
-        if (rng < 0).any():
+        if (rng < 0).any():  # type: ignore
             raise ValueError("ground distance must be >= 0")
     except NameError:
-        if abs(lat1) > pi / 2:
+        if abs(lat1) > pi / 2:  # type: ignore
             raise ValueError("-90 <= latitude <= 90")
         if rng < 0:
             raise ValueError("ground distance must be >= 0")
@@ -226,14 +245,23 @@ def loxodrome_direct(
     newiso = geodetic2isometric(lat2, ell, deg=False)
     iso = geodetic2isometric(lat1, ell, deg=False)
 
+    # stability near singularities
+    i = abs(cos(a12)) < COS_EPS
     dlon = tan(a12) * (newiso - iso)
+
+    try:
+        dlon[i] = sign(pi - a12[i]) * rng[i] / rcurve.parallel(lat1[i], ell=ell, deg=False)  # type: ignore
+    except (AttributeError, TypeError):
+        if i:  # straight east or west
+            dlon = sign(pi - a12) * rng / rcurve.parallel(lat1, ell=ell, deg=False)
+
     lon2 = lon1 + dlon
 
     if deg:
         lat2, lon2 = degrees(lat2), degrees(lon2)
 
     try:
-        return lat2.squeeze()[()], lon2.squeeze()[()]
+        return lat2.squeeze()[()], lon2.squeeze()[()]  # type: ignore
     except AttributeError:
         return lat2, lon2
 
@@ -265,12 +293,12 @@ def departure(
     if deg:
         lon1, lon2, lat = radians(lon1), radians(lon2), radians(lat)
 
-    return rcurve.parallel(lat, ell, deg=False) * ((lon2 - lon1) % pi)
+    return rcurve.parallel(lat, ell=ell, deg=False) * ((lon2 - lon1) % pi)
 
 
 def meanm(
     lat: ndarray, lon: ndarray, ell: Ellipsoid = None, deg: bool = True
-) -> tuple[float | ndarray, float | ndarray]:
+) -> tuple[ndarray, ndarray]:
     """
     Computes geographic mean for geographic points on an ellipsoid
 
@@ -297,8 +325,8 @@ def meanm(
         lat, lon = radians(lat), radians(lon)
 
     lat = geodetic2authalic(lat, ell, deg=False)
-    assert isinstance(lat, ndarray)
-    x, y, z = sph2cart(lon, lat, 1)
+
+    x, y, z = sph2cart(lon, lat, array(1.0))
     lonbar, latbar, _ = cart2sph(x.sum(), y.sum(), z.sum())
     latbar = authalic2geodetic(latbar, ell, deg=False)
 
